pyjabber.plugins.xep\_0199 package
==================================

Submodules
----------

pyjabber.plugins.xep\_0199.xep\_0199 module
-------------------------------------------

.. automodule:: pyjabber.plugins.xep_0199.xep_0199
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.plugins.xep_0199
   :members:
   :undoc-members:
   :show-inheritance:
